Module: Google::Apis::WebcontentpublisherV1
- Defined in:
- lib/google/apis/webcontentpublisher_v1.rb,
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/service.rb,
lib/google/apis/webcontentpublisher_v1/gem_version.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb
Overview
Web Content Publisher API
webcontentpublisher.googleapis.com API, a service for web content publishers.
Defined Under Namespace
Classes: CheckFreeAccessResponse, ContentPolicyStatus, Cta, DomainProperty, ListCtasResponse, ListPublicationsResponse, NewsletterConfig, Publication, RrmProduct, SlProduct, TosAcceptance, WebContentPublisherService
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-webcontentpublisher_v1 gem
"0.3.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260629"- VERSION =
Version of the Web Content Publisher API this client connects to. This is NOT the gem version.
'V1'- AUTH_SUBSCRIBEWITHGOOGLE_PUBLICATIONS_ENTITLEMENTS_MANAGE =
'https://www.googleapis.com/auth/subscribewithgoogle.publications.entitlements.manage'- AUTH_SUBSCRIBEWITHGOOGLE_PUBLICATIONS_ENTITLEMENTS_READONLY =
See and review your subscription information
'https://www.googleapis.com/auth/subscribewithgoogle.publications.entitlements.readonly'