Class: Google::Apis::WebcontentpublisherV1::CheckFreeAccessResponse
- Inherits:
-
Object
- Object
- Google::Apis::WebcontentpublisherV1::CheckFreeAccessResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb
Overview
Response message for CheckFreeAccess
Instance Attribute Summary collapse
-
#is_allowed ⇒ Boolean
(also: #is_allowed?)
True if free access should be allowed, false otherwise.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckFreeAccessResponse
constructor
A new instance of CheckFreeAccessResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckFreeAccessResponse
Returns a new instance of CheckFreeAccessResponse.
35 36 37 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 35 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_allowed ⇒ Boolean Also known as: is_allowed?
True if free access should be allowed, false otherwise.
Corresponds to the JSON property isAllowed
32 33 34 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 32 def is_allowed @is_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40 41 42 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 40 def update!(**args) @is_allowed = args[:is_allowed] if args.key?(:is_allowed) end |