Class: Google::Apis::WebcontentpublisherV1::ListCtasResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Response message for ListCtas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCtasResponse

Returns a new instance of ListCtasResponse.



157
158
159
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ctasArray<Google::Apis::WebcontentpublisherV1::Cta>

Output only. The list of CTAs. Corresponds to the JSON property ctas



149
150
151
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 149

def ctas
  @ctas
end

#next_page_tokenString

Output only. A token to retrieve the next page of results, or empty if there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


155
156
157
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 155

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



162
163
164
165
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 162

def update!(**args)
  @ctas = args[:ctas] if args.key?(:ctas)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end