Class: Google::Apis::WebcontentpublisherV1::ListPublicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Response message for ListPublications.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPublicationsResponse

Returns a new instance of ListPublicationsResponse.



215
216
217
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Output only. A token to retrieve the next page of results, or empty if there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


208
209
210
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 208

def next_page_token
  @next_page_token
end

#publicationsArray<Google::Apis::WebcontentpublisherV1::Publication>

Output only. The list of publications. Corresponds to the JSON property publications



213
214
215
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 213

def publications
  @publications
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



220
221
222
223
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 220

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @publications = args[:publications] if args.key?(:publications)
end