Class: Google::Apis::WebcontentpublisherV1::Publication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Represents a publisher's publication in Reader Revenue Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Publication

Returns a new instance of Publication.



366
367
368
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_domainsArray<Google::Apis::WebcontentpublisherV1::DomainProperty>

Optional. Additional domain properties verified for the publication. Corresponds to the JSON property additionalDomains



278
279
280
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 278

def additional_domains
  @additional_domains
end

#content_policy_statusGoogle::Apis::WebcontentpublisherV1::ContentPolicyStatus

The content policy status of the publication, indicating any violations. Corresponds to the JSON property contentPolicyStatus



283
284
285
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 283

def content_policy_status
  @content_policy_status
end

#display_nameString

Required. The user-visible display name of the publication. Corresponds to the JSON property displayName

Returns:

  • (String)


288
289
290
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 288

def display_name
  @display_name
end

#language_codeString

Required. The primary language of the publication (BCP-47 code, e.g., "en-US"). Corresponds to the JSON property languageCode

Returns:

  • (String)


293
294
295
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 293

def language_code
  @language_code
end

#nameString

Identifier. The resource name of the publication. Format: organizations/ organization/publications/publication Corresponds to the JSON property name

Returns:

  • (String)


299
300
301
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 299

def name
  @name
end

#onboarding_stateString

Output only. The current onboarding state. Corresponds to the JSON property onboardingState

Returns:

  • (String)


304
305
306
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 304

def onboarding_state
  @onboarding_state
end

#organization_idString

Output only. The unique identifier of the organization that owns this publication. Corresponds to the JSON property organizationId

Returns:

  • (String)


310
311
312
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 310

def organization_id
  @organization_id
end

#payment_optionString

Output only. The configured payment option. Corresponds to the JSON property paymentOption

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 315

def payment_option
  @payment_option
end

#primary_domainGoogle::Apis::WebcontentpublisherV1::DomainProperty

Represents a domain property associated with a publication, typically used to verify ownership and scope access. Corresponds to the JSON property primaryDomain



321
322
323
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 321

def primary_domain
  @primary_domain
end

#productsArray<String>

Output only. The list of active products/features enabled for this publication. Corresponds to the JSON property products

Returns:

  • (Array<String>)


326
327
328
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 326

def products
  @products
end

#publication_idString

Output only. The unique identifier of the publication. Corresponds to the JSON property publicationId

Returns:

  • (String)


331
332
333
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 331

def publication_id
  @publication_id
end

#publication_privacy_policy_urlString

Optional. The URL to the publisher's Privacy Policy. Corresponds to the JSON property publicationPrivacyPolicyUrl

Returns:

  • (String)


336
337
338
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 336

def publication_privacy_policy_url
  @publication_privacy_policy_url
end

#publication_tos_urlString

Optional. The URL to the publisher's own Terms of Service. Corresponds to the JSON property publicationTosUrl

Returns:

  • (String)


341
342
343
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 341

def publication_tos_url
  @publication_tos_url
end

#publication_typeString

Optional. The publication entity type (for-profit vs non-profit). Defaults to FOR_PROFIT if omitted. Corresponds to the JSON property publicationType

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 347

def publication_type
  @publication_type
end

#region_codeString

Required. The ISO 3166-1 alpha-2 region code where the publication is registered (e.g., "US"). Corresponds to the JSON property regionCode

Returns:

  • (String)


353
354
355
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 353

def region_code
  @region_code
end

#rrm_productGoogle::Apis::WebcontentpublisherV1::RrmProduct

Configuration and status of the Reader Revenue Manager (RRM) product for a publication. Corresponds to the JSON property rrmProduct



359
360
361
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 359

def rrm_product
  @rrm_product
end

#sl_productGoogle::Apis::WebcontentpublisherV1::SlProduct

Subscription Linking (SL) product settings and status. Corresponds to the JSON property slProduct



364
365
366
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 364

def sl_product
  @sl_product
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 371

def update!(**args)
  @additional_domains = args[:additional_domains] if args.key?(:additional_domains)
  @content_policy_status = args[:content_policy_status] if args.key?(:content_policy_status)
  @display_name = args[:display_name] if args.key?(:display_name)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @onboarding_state = args[:onboarding_state] if args.key?(:onboarding_state)
  @organization_id = args[:organization_id] if args.key?(:organization_id)
  @payment_option = args[:payment_option] if args.key?(:payment_option)
  @primary_domain = args[:primary_domain] if args.key?(:primary_domain)
  @products = args[:products] if args.key?(:products)
  @publication_id = args[:publication_id] if args.key?(:publication_id)
  @publication_privacy_policy_url = args[:publication_privacy_policy_url] if args.key?(:publication_privacy_policy_url)
  @publication_tos_url = args[:publication_tos_url] if args.key?(:publication_tos_url)
  @publication_type = args[:publication_type] if args.key?(:publication_type)
  @region_code = args[:region_code] if args.key?(:region_code)
  @rrm_product = args[:rrm_product] if args.key?(:rrm_product)
  @sl_product = args[:sl_product] if args.key?(:sl_product)
end