Class: Google::Apis::WebcontentpublisherV1::RrmProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Configuration and status of the Reader Revenue Manager (RRM) product for a publication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrmProduct

Returns a new instance of RrmProduct.



413
414
415
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Whether the RRM product is enabled for the publication. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


400
401
402
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 400

def enabled
  @enabled
end

#product_tos_urlString

Output only. The URL to the product-specific Terms of Service. Corresponds to the JSON property productTosUrl

Returns:

  • (String)


406
407
408
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 406

def product_tos_url
  @product_tos_url
end

#tos_acceptanceGoogle::Apis::WebcontentpublisherV1::TosAcceptance

Details about the acceptance of the Terms of Service (TOS). Corresponds to the JSON property tosAcceptance



411
412
413
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 411

def tos_acceptance
  @tos_acceptance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



418
419
420
421
422
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 418

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @product_tos_url = args[:product_tos_url] if args.key?(:product_tos_url)
  @tos_acceptance = args[:tos_acceptance] if args.key?(:tos_acceptance)
end