Module: Google::Apis::WebcontentpublisherV1
- Defined in:
- lib/google/apis/webcontentpublisher_v1.rb,
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/service.rb,
lib/google/apis/webcontentpublisher_v1/gem_version.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb
Overview
Web Content Publisher API
webcontentpublisher.googleapis.com API, a service for web content publishers.
Defined Under Namespace
Classes: CheckFreeAccessResponse, WebContentPublisherService
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-webcontentpublisher_v1 gem
"0.1.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260526"- VERSION =
Version of the Web Content Publisher API this client connects to. This is NOT the gem version.
'V1'- AUTH_SUBSCRIBEWITHGOOGLE_PUBLICATIONS_ENTITLEMENTS_READONLY =
See and review your subscription information
'https://www.googleapis.com/auth/subscribewithgoogle.publications.entitlements.readonly'