Class: Google::Apis::WebcontentpublisherV1::ContentPolicyStatus
- Inherits:
-
Object
- Object
- Google::Apis::WebcontentpublisherV1::ContentPolicyStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb
Overview
The content policy status of the publication, indicating any violations.
Instance Attribute Summary collapse
-
#policy_info_url ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentPolicyStatus
constructor
A new instance of ContentPolicyStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentPolicyStatus
Returns a new instance of ContentPolicyStatus.
59 60 61 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 59 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_info_url ⇒ String
Output only. URL pointing to more details about the policy violation or status.
Corresponds to the JSON property policyInfoUrl
52 53 54 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 52 def policy_info_url @policy_info_url end |
#state ⇒ String
Output only. The current policy state.
Corresponds to the JSON property state
57 58 59 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 57 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64 65 66 67 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 64 def update!(**args) @policy_info_url = args[:policy_info_url] if args.key?(:policy_info_url) @state = args[:state] if args.key?(:state) end |