Class: Google::Apis::WebcontentpublisherV1::ListPublicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Response message for ListPublications.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPublicationsResponse

Returns a new instance of ListPublicationsResponse.



183
184
185
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Output only. A token to retrieve the next page of results, or empty if there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


176
177
178
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 176

def next_page_token
  @next_page_token
end

#publicationsArray<Google::Apis::WebcontentpublisherV1::Publication>

Output only. The list of publications. Corresponds to the JSON property publications



181
182
183
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 181

def publications
  @publications
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



188
189
190
191
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 188

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @publications = args[:publications] if args.key?(:publications)
end