Class: Google::Apis::WebcontentpublisherV1::Publication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Represents a publisher's publication in Reader Revenue Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Publication

Returns a new instance of Publication.



321
322
323
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_domainsArray<Google::Apis::WebcontentpublisherV1::DomainProperty>

Optional. Additional domain properties verified for the publication. Corresponds to the JSON property additionalDomains



239
240
241
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 239

def additional_domains
  @additional_domains
end

#content_policy_statusGoogle::Apis::WebcontentpublisherV1::ContentPolicyStatus

The content policy status of the publication, indicating any violations. Corresponds to the JSON property contentPolicyStatus



244
245
246
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 244

def content_policy_status
  @content_policy_status
end

#display_nameString

Required. The user-visible display name of the publication. Corresponds to the JSON property displayName

Returns:

  • (String)


249
250
251
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 249

def display_name
  @display_name
end

#language_codeString

Required. The primary language of the publication (BCP-47 code, e.g., "en-US"). Corresponds to the JSON property languageCode

Returns:

  • (String)


254
255
256
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 254

def language_code
  @language_code
end

#nameString

Identifier. The resource name of the publication. Format: organizations/ organization/publications/publication Corresponds to the JSON property name

Returns:

  • (String)


260
261
262
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 260

def name
  @name
end

#onboarding_stateString

Output only. The current onboarding state. Corresponds to the JSON property onboardingState

Returns:

  • (String)


265
266
267
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 265

def onboarding_state
  @onboarding_state
end

#organization_idString

Output only. The unique identifier of the organization that owns this publication. Corresponds to the JSON property organizationId

Returns:

  • (String)


271
272
273
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 271

def organization_id
  @organization_id
end

#payment_optionString

Output only. The configured payment option. Corresponds to the JSON property paymentOption

Returns:

  • (String)


276
277
278
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 276

def payment_option
  @payment_option
end

#primary_domainGoogle::Apis::WebcontentpublisherV1::DomainProperty

Represents a domain property associated with a publication, typically used to verify ownership and scope access. Corresponds to the JSON property primaryDomain



282
283
284
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 282

def primary_domain
  @primary_domain
end

#productsArray<String>

Output only. The list of active products/features enabled for this publication. Corresponds to the JSON property products

Returns:

  • (Array<String>)


287
288
289
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 287

def products
  @products
end

#publication_idString

Output only. The unique identifier of the publication. Corresponds to the JSON property publicationId

Returns:

  • (String)


292
293
294
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 292

def publication_id
  @publication_id
end

#publication_privacy_policy_urlString

Optional. The URL to the publisher's Privacy Policy. Corresponds to the JSON property publicationPrivacyPolicyUrl

Returns:

  • (String)


297
298
299
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 297

def publication_privacy_policy_url
  @publication_privacy_policy_url
end

#publication_tos_urlString

Optional. The URL to the publisher's own Terms of Service. Corresponds to the JSON property publicationTosUrl

Returns:

  • (String)


302
303
304
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 302

def publication_tos_url
  @publication_tos_url
end

#region_codeString

Required. The ISO 3166-1 alpha-2 region code where the publication is registered (e.g., "US"). Corresponds to the JSON property regionCode

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 308

def region_code
  @region_code
end

#rrm_productGoogle::Apis::WebcontentpublisherV1::RrmProduct

Configuration and status of the Reader Revenue Manager (RRM) product for a publication. Corresponds to the JSON property rrmProduct



314
315
316
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 314

def rrm_product
  @rrm_product
end

#sl_productGoogle::Apis::WebcontentpublisherV1::SlProduct

Subscription Linking (SL) product settings and status. Corresponds to the JSON property slProduct



319
320
321
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 319

def sl_product
  @sl_product
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 326

def update!(**args)
  @additional_domains = args[:additional_domains] if args.key?(:additional_domains)
  @content_policy_status = args[:content_policy_status] if args.key?(:content_policy_status)
  @display_name = args[:display_name] if args.key?(:display_name)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @onboarding_state = args[:onboarding_state] if args.key?(:onboarding_state)
  @organization_id = args[:organization_id] if args.key?(:organization_id)
  @payment_option = args[:payment_option] if args.key?(:payment_option)
  @primary_domain = args[:primary_domain] if args.key?(:primary_domain)
  @products = args[:products] if args.key?(:products)
  @publication_id = args[:publication_id] if args.key?(:publication_id)
  @publication_privacy_policy_url = args[:publication_privacy_policy_url] if args.key?(:publication_privacy_policy_url)
  @publication_tos_url = args[:publication_tos_url] if args.key?(:publication_tos_url)
  @region_code = args[:region_code] if args.key?(:region_code)
  @rrm_product = args[:rrm_product] if args.key?(:rrm_product)
  @sl_product = args[:sl_product] if args.key?(:sl_product)
end