Class: Google::Apis::WebcontentpublisherV1::TosAcceptance
- Inherits:
-
Object
- Object
- Google::Apis::WebcontentpublisherV1::TosAcceptance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb
Overview
Details about the acceptance of the Terms of Service (TOS).
Instance Attribute Summary collapse
-
#email_opt_in ⇒ Boolean
(also: #email_opt_in?)
Optional.
-
#signer ⇒ String
Optional.
-
#signer_title ⇒ String
Optional.
-
#user_accepted ⇒ Boolean
(also: #user_accepted?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
503 504 505 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 503 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email_opt_in ⇒ Boolean Also known as: email_opt_in?
Optional. Whether the user opted in to receive product updates and email
communications.
Corresponds to the JSON property emailOptIn
484 485 486 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 484 def email_opt_in @email_opt_in end |
#signer ⇒ String
Optional. The name of the person who accepted the TOS.
Corresponds to the JSON property signer
490 491 492 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 490 def signer @signer end |
#signer_title ⇒ String
Optional. The job title or role of the signer.
Corresponds to the JSON property signerTitle
495 496 497 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 495 def signer_title @signer_title end |
#user_accepted ⇒ Boolean Also known as: user_accepted?
Required. Whether the user has accepted the Terms of Service.
Corresponds to the JSON property userAccepted
500 501 502 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 500 def user_accepted @user_accepted end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
508 509 510 511 512 513 |
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 508 def update!(**args) @email_opt_in = args[:email_opt_in] if args.key?(:email_opt_in) @signer = args[:signer] if args.key?(:signer) @signer_title = args[:signer_title] if args.key?(:signer_title) @user_accepted = args[:user_accepted] if args.key?(:user_accepted) end |