Class: Google::Apis::WebcontentpublisherV1::TosAcceptance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Details about the acceptance of the Terms of Service (TOS).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



439
440
441
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_opt_inBoolean Also known as: email_opt_in?

Optional. Whether the user opted in to receive product updates and email communications. Corresponds to the JSON property emailOptIn

Returns:

  • (Boolean)


420
421
422
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 420

def email_opt_in
  @email_opt_in
end

#signerString

Optional. The name of the person who accepted the TOS. Corresponds to the JSON property signer

Returns:

  • (String)


426
427
428
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 426

def signer
  @signer
end

#signer_titleString

Optional. The job title or role of the signer. Corresponds to the JSON property signerTitle

Returns:

  • (String)


431
432
433
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 431

def signer_title
  @signer_title
end

#user_acceptedBoolean Also known as: user_accepted?

Required. Whether the user has accepted the Terms of Service. Corresponds to the JSON property userAccepted

Returns:

  • (Boolean)


436
437
438
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 436

def user_accepted
  @user_accepted
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



444
445
446
447
448
449
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 444

def update!(**args)
  @email_opt_in = args[:email_opt_in] if args.key?(:email_opt_in)
  @signer = args[:signer] if args.key?(:signer)
  @signer_title = args[:signer_title] if args.key?(:signer_title)
  @user_accepted = args[:user_accepted] if args.key?(:user_accepted)
end