Class: Google::Apis::WebcontentpublisherV1::TosAcceptance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/webcontentpublisher_v1/classes.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb,
lib/google/apis/webcontentpublisher_v1/representations.rb

Overview

Details about the acceptance of the Terms of Service (TOS).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



425
426
427
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#signerString

Optional. The name of the person who accepted the TOS. Corresponds to the JSON property signer

Returns:

  • (String)


412
413
414
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 412

def signer
  @signer
end

#signer_titleString

Optional. The job title or role of the signer. Corresponds to the JSON property signerTitle

Returns:

  • (String)


417
418
419
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 417

def signer_title
  @signer_title
end

#user_acceptedBoolean Also known as: user_accepted?

Required. Whether the user has accepted the Terms of Service. Corresponds to the JSON property userAccepted

Returns:

  • (Boolean)


422
423
424
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 422

def user_accepted
  @user_accepted
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



430
431
432
433
434
# File 'lib/google/apis/webcontentpublisher_v1/classes.rb', line 430

def update!(**args)
  @signer = args[:signer] if args.key?(:signer)
  @signer_title = args[:signer_title] if args.key?(:signer_title)
  @user_accepted = args[:user_accepted] if args.key?(:user_accepted)
end