Class: Google::Apis::WebcontentpublisherV1::WebContentPublisherService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/webcontentpublisher_v1/service.rb

Overview

Web Content Publisher API

webcontentpublisher.googleapis.com API, a service for web content publishers.

Examples:

require 'google/apis/webcontentpublisher_v1'

Webcontentpublisher = Google::Apis::WebcontentpublisherV1 # Alias the module
service = Webcontentpublisher::WebContentPublisherService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://webcontentpublisher.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeWebContentPublisherService

Returns a new instance of WebContentPublisherService.



47
48
49
50
51
52
# File 'lib/google/apis/webcontentpublisher_v1/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-webcontentpublisher_v1',
        client_version: Google::Apis::WebcontentpublisherV1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/webcontentpublisher_v1/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/webcontentpublisher_v1/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#check_publication_free_access(name, http_referrer: nil, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WebcontentpublisherV1::CheckFreeAccessResponse

Checks if a user is eligible for free article access.

Parameters:

  • name (String)

    Required. The resource name of the publication. Format: publications/ publication_id

  • http_referrer (String) (defaults to: nil)

    Required. The HTTP referrer.

  • uri (String) (defaults to: nil)

    Required. The URI of the content.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



79
80
81
82
83
84
85
86
87
88
89
# File 'lib/google/apis/webcontentpublisher_v1/service.rb', line 79

def check_publication_free_access(name, http_referrer: nil, uri: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}:checkFreeAccess', options)
  command.response_representation = Google::Apis::WebcontentpublisherV1::CheckFreeAccessResponse::Representation
  command.response_class = Google::Apis::WebcontentpublisherV1::CheckFreeAccessResponse
  command.params['name'] = name unless name.nil?
  command.query['httpReferrer'] = http_referrer unless http_referrer.nil?
  command.query['uri'] = uri unless uri.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end